@@ -26,13 +26,13 @@ class СтильДруку(enum.Enum):
     UNDERLINE = '\033[4m'
 
     @staticmethod
-    def за_замовчуванням():
+    def замовчання():
         return СтильДруку.СТАНДАРТНИЙ
 
     @staticmethod
     def отримати(стиль):
         if стиль is Жоден:
-            обраний_стиль = СтильДруку.за_замовчуванням()
+            обраний_стиль = СтильДруку.замовчання()
         elif є_екземпляром(стиль, СтильДруку):
             обраний_стиль = стиль
         else:
@@ -40,7 +40,7 @@ class СтильДруку(enum.Enum):
 
             обраний_стиль = отримати_атрибут(СтильДруку, підготовлена_назва, Жоден)
             if обраний_стиль is Жоден:
-                обраний_стиль = СтильДруку.за_замовчуванням()
+                обраний_стиль = СтильДруку.замовчання()
         return обраний_стиль
 
 PrintStyle = СтильДруку
@@ -65,22 +65,21 @@ def надрукувати(текст, *арг, розд=' ', закінченн
 
     print(текст, *арг, sep=розд, end=закінчення, file=файл)
 
-
 def є_екземпляром(змінна, тип_данних):  # real signature unknown; restored from __doc__
     """
-    Повертає "істина" якщо "змінна" є екземляром класу або підкласу вказаному у "тип_даних"
+    Повертає "істина" якщо "змінна" є екземляром классу або підкласу вказаному у "тип_данних"
     """
     return isinstance(змінна, тип_данних)
 
-
-def отримати_атрибут(обєкт, імя, за_замовчуванням=Жоден):  # known special case of getattr
+def отримати_атрибут(обєкт, імя, за_замовчанням=Жоден):  # known special case of getattr
     """
     getattr(обєкт, імя[, за_замовчанням]) -> значення
 
     Отримання значення атрибуту за його ім'ям;
-    отримати_атрибут(x, 'y') еквівалентне до x.y
+    отримати_атрибут(x, 'y') еквівалентне до x.y.
 
-    При наявності аргументу "за_замовчуванням" функція повертає його при відсутності.
-    Інакше викликається переривання.
+    Коли задан параметра "за_замовчанням" то функція повертає його коли атрибута
+    не існує в іншому випадку ініціюється виключна ситуація
     """
-    return getattr(обєкт, імя, за_замовчуванням)
+    return getattr(обєкт, імя, за_замовчанням)
+
